// ----------------------------------------------------------------------
// termBlaster - The context search extension
//  @copyright 2006 David Duong
//  @version $Id: options.js,v 1.10 2006/03/01 22:29:05 davidnqd Exp $
// ----------------------------------------------------------------------
// LICENSE
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License (GPL)
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// You should have recieved the lincence included with the disribution.
// If not visit http://www.gnu.org/copyleft/gpl.html
// ----------------------------------------------------------------------
var TermBlasterOptions = {
  /**
   * Load values into window
   */
  onLoad: function() {
    this.txtDatabaseLocation = document.getElementById("txtDatabaseLocation");
    this.txtQuickListLocation = document.getElementById("txtQuickListLocation");
    this.rgDestination = document.getElementById("rgDestination");
    this.cbQuote = document.getElementById("cbQuote");
    this.cbFocus = document.getElementById("cbFocus");

    this.populate(this.txtDatabaseLocation);
    this.populate(this.txtQuickListLocation);

   this.displayPrefs();
  },

  /**
   * Open a browse dialog
   *
   * @param txtField Textfield where the selected file will be displayed
   */
  btnBrowseCommand: function(txtField) {
    var nsIFilePicker = Components.interfaces.nsIFilePicker;
    var fp = Components.classes["@mozilla.org/filepicker;1"].createInstance(nsIFilePicker);

    fp.init(window, "Select a File", nsIFilePicker.modeOpen);
    fp.appendFilter("termBlaster Files", "*.tbd; *.tbq");

    if (fp.show() == nsIFilePicker.returnOK && fp.fileURL.spec && fp.fileURL.spec.length > 0) {
      var thefile = fp.file;
      txtField.value = fp.fileURL.spec;
    }
  },

  reloadMenus: function() {
    Components.classes["@mozilla.org/observer-service;1"]
       .getService(Components.interfaces.nsIObserverService)
       .notifyObservers(null, "TermBlasterOptions_reloadMenus", null);
  },

  /**
   * Commit changes
   */
  btnOkCommand: function() {
    var prefs = Components.classes["@mozilla.org/preferences-service;1"].
                    getService(Components.interfaces.nsIPrefBranch);

    prefs.setCharPref("extensions.termblaster.opened.database", this.txtDatabaseLocation.value);
    prefs.setCharPref("extensions.termblaster.opened.quicklist", this.txtQuickListLocation.value);
    prefs.setIntPref("extensions.termblaster.destination", this.rgDestination.selectedIndex);
    prefs.setBoolPref("extensions.termblaster.quote", this.cbQuote.checked);
    prefs.setBoolPref("extensions.termblaster.focus", this.cbFocus.checked);

    this.reloadMenus();
  },

  /**
   * Grab preferences and display them
   */
  displayPrefs: function() {
    try {
      var prefs = Components.classes["@mozilla.org/preferences-service;1"].
                    getService(Components.interfaces.nsIPrefBranch);
      this.txtDatabaseLocation.value = prefs.getCharPref("extensions.termblaster.opened.database");
      this.txtQuickListLocation.value = prefs.getCharPref("extensions.termblaster.opened.quicklist");
      this.rgDestination.selectedIndex = prefs.getIntPref("extensions.termblaster.destination");
      this.cbQuote.checked = prefs.getBoolPref("extensions.termblaster.quote");
      this.cbFocus.checked = prefs.getBoolPref("extensions.termblaster.focus");
    } catch (e) {
      alert("termBlaster could not load preferences: " + e.message);
    }
  },

  /**
   * Reset changes
   */
  resetFields: function() {
    var prefs = Components.classes["@mozilla.org/preferences-service;1"].
                                getService(Components.interfaces.nsIPrefBranch);
    try {
      prefs.clearUserPref("extensions.termblaster.opened.database");
    } catch (e) {}
    try {
      prefs.clearUserPref("extensions.termblaster.opened.quicklist");
    } catch (e) {}
    try {
      prefs.clearUserPref("extensions.termblaster.destination");
    } catch (e) {}
    try {
      prefs.clearUserPref("extensions.termblaster.quote");
    } catch (e) {}
    try {
      prefs.clearUserPref("extensions.termblaster.focus");
    } catch (e) {}


    window.close();
  },

  /**
   * Dynamically generate files list
   *
   * @param menulist Menulist where the file list should be displayed
   */
  populate: function(menulist) {
    const id = "termblaster@forizon.com";
    var ext = Components.classes["@mozilla.org/extensions/manager;1"]
                  .getService(Components.interfaces.nsIExtensionManager)
                  .getInstallLocation(id)
                  .getItemLocation(id);
    var ios = Components.classes["@mozilla.org/network/io-service;1"]
                  .getService(Components.interfaces.nsIIOService);
    var fileHandler = ios.getProtocolHandler("file")
                  .QueryInterface(Components.interfaces.nsIFileProtocolHandler);

    ext.append("content");
    ext.append("data");

    var entries = ext.directoryEntries;
    var basename;
    while(entries.hasMoreElements())
    {
      var entry = entries.getNext();
      entry.QueryInterface(Components.interfaces.nsIFile);
      basename = fileHandler.getURLSpecFromFile(entry).replace(/.*\//, "");
      if (basename != '') {
        menulist.appendItem('chrome://termblaster/content/data/' + basename);
      }
    }

/*
    var header = menulist.appendItem('Previously Opened Files:');
    header.setAttribute("disabled", "true");
    var seperator = document.createElementNS("http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul", "menuseparator");
    header.parentNode.appendChild(seperator);
*/
  }
};
